Welcome to CM4AI Generate Hierarchy's documentation!
================================================================


.. image:: https://img.shields.io/pypi/v/cellmaps_generate_hierarchy.svg
        :target: https://pypi.python.org/pypi/cellmaps_generate_hierarchy

.. image:: https://img.shields.io/travis/idekerlab/cellmaps_generate_hierarchy.svg
        :target: https://travis-ci.com/idekerlab/cellmaps_generate_hierarchy

.. image:: https://readthedocs.org/projects/cellmaps-generate-hierarchy/badge/?version=latest
        :target: https://cellmaps-generate-hierarchy.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Python Boilerplate contains all the boilerplate you need to create a Python package with command line


* Free software: MIT license


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation
   usage
   modules
   developer
   authors
   history

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
